@@ -1,4 +1,3 @@
-
 """
 Jac's set class for Jaseci
 
@@ -16,20 +15,19 @@ class jac_set(list):
     """
 
     def __init__(self, in_list=None):
-        if (in_list):
+        if in_list:
             for i in in_list:
-                if(i not in self):
+                if i not in self:
                     self.append(i)
 
     def append(self, item):
-        if(not isinstance(item, element) or not hasattr(item, 'anchor_value')):
-            logger.error(
-                f"Invalid {type(item)} object {item} to be added to jac_set!")
-        elif(item not in self):
+        if not isinstance(item, element) or not hasattr(item, "anchor_value"):
+            logger.error(f"Invalid {type(item)} object {item} to be added to jac_set!")
+        elif item not in self:
             list.append(self, item)
 
     def add_obj(self, item):
-        if(item not in self):
+        if item not in self:
             self.append(item)
 
     def obj_list(self):
@@ -39,7 +37,7 @@ class jac_set(list):
         """Returns reduced set where anchor value evals to other"""
         ret = jac_set()
         for i in self:
-            if (i.anchor_value() < other):
+            if i.anchor_value() < other:
                 ret.add_obj(i)
         return ret
 
@@ -47,7 +45,7 @@ class jac_set(list):
         """Returns reduced set where anchor value evals to other"""
         ret = jac_set()
         for i in self:
-            if (i.anchor_value() > other):
+            if i.anchor_value() > other:
                 ret.add_obj(i)
         return ret
 
@@ -55,7 +53,7 @@ class jac_set(list):
         """Returns reduced set where anchor value evals to other"""
         ret = jac_set()
         for i in self:
-            if (i.anchor_value() <= other):
+            if i.anchor_value() <= other:
                 ret.add_obj(i)
         return ret
 
@@ -63,7 +61,7 @@ class jac_set(list):
         """Returns reduced set where anchor value evals to other"""
         ret = jac_set()
         for i in self:
-            if (i.anchor_value() >= other):
+            if i.anchor_value() >= other:
                 ret.add_obj(i)
         return ret
 
@@ -71,7 +69,7 @@ class jac_set(list):
         """Returns reduced set where anchor value evals to other"""
         ret = jac_set()
         for i in self:
-            if (i.anchor_value() == other):
+            if i.anchor_value() == other:
                 ret.add_obj(i)
         return ret
 
@@ -79,7 +77,7 @@ class jac_set(list):
         """Returns reduced set where anchor value evals to other"""
         ret = jac_set()
         for i in self:
-            if (i.anchor_value() != other):
+            if i.anchor_value() != other:
                 ret.add_obj(i)
         return ret
 
@@ -89,7 +87,7 @@ class jac_set(list):
         for i in self:
             ret.add_obj(i)
         for i in other:
-            if (i not in ret):
+            if i not in ret:
                 ret.add_obj(i)
         return ret
 
@@ -97,7 +95,7 @@ class jac_set(list):
         """Returns new set with operation applied"""
         ret = jac_set()
         for i in self:
-            if(i not in other):
+            if i not in other:
                 ret.add_obj(i)
         return ret
 
@@ -105,7 +103,7 @@ class jac_set(list):
         """Returns new set with operation applied, mul is intersection"""
         ret = jac_set()
         for i in self:
-            if(i in other):
+            if i in other:
                 ret.add_obj(i)
         return ret
 
@@ -113,9 +111,9 @@ class jac_set(list):
         """Returns new set with operation applied, div is 'outersection'"""
         ret = jac_set()
         for i in self:
-            if(i not in other):
+            if i not in other:
                 ret.add_obj(i)
         for i in other:
-            if(i not in self):
+            if i not in self:
                 ret.add_obj(i)
         return ret
