@@ -232,6 +232,15 @@ class jsctl_test(TestCaseHelper, TestCase):
         r = self.call_cast("walker run init")
         self.assertEqual(r["report"][0], "plain")
 
+    def test_jsctl_import_path(self):
+        self.call(
+            "sentinel register "
+            "jaseci/jsctl/tests/base6.jac -code_dir jaseci/jsctl/tests/ "
+            "-set_active true"
+        )
+        r = self.call_cast("walker run init")
+        self.assertEqual(r["report"][0], "plain")
+
     def test_jsctl_run_tests(self):
         self.call("sentinel register " "jaseci/jsctl/tests/teststest.jac")
         r = self.call_split("sentinel test")
@@ -323,3 +332,24 @@ class jsctl_test(TestCaseHelper, TestCase):
         )
         r = self.call("walker run go")
         self.assertEqual(r.split()[0], "2020-01-01T00:00:00")
+
+    def test_jsctl_custom_report(self):
+        self.call(
+            "sentinel register " "jaseci/jsctl/tests/glob_imp.jac -set_active true"
+        )
+        r = self.call_cast("walker run cust_report")
+        self.assertEqual(r, {"a": "b"})
+
+    def test_jsctl_custom_report_off(self):
+        self.call(
+            "sentinel register " "jaseci/jsctl/tests/glob_imp.jac -set_active true"
+        )
+        r = self.call_cast("walker run cust_report_neutralize")
+        self.assertIn("success", r.keys())
+
+    def test_jsctl_disengage_report(self):
+        self.call(
+            "sentinel register " "jaseci/jsctl/tests/glob_imp.jac -set_active true"
+        )
+        r = self.call_cast("walker run disengage_report")
+        self.assertEqual(r, {"a": "b"})
