@@ -271,3 +271,41 @@ reffy_deref_check = """
         report *&actual_answer == *nd.expected_answer;
     }
     """
+
+vanishing_can_check = """
+    node plain {
+        has name;
+        can infer.year_from_date;
+    }
+
+    walker init {
+        root {
+            take --> node::plain else {
+                nd=spawn here --> node::plain;
+                report nd.info['jid'];
+                disengage;
+            }
+        }
+        plain {
+            report infer.year_from_date("2022-05-05");
+        }
+    }
+    """
+
+jasecilib_alias_list = """
+    walker init {
+        report jaseci.alias_list();
+    }
+    """
+
+jasecilib_params = """
+    walker init {
+        report jaseci.graph_list(true);
+    }
+    """
+
+jasecilib_create_user = """
+    walker init {
+        report jaseci.master_create("daman@gmail.com");
+    }
+    """
